@@ -1,6 +1,6 @@
 context("Unit tests for the accounts endpoint, where details about specific accounts are returned only.")
 
-valid_pk = "GA2HGBJIJKI6O4XEM7CZWY5PS6GKSXL6D34ERAJYQSPYA6X6AI7HYW36"
+valid_pk = test_account_1 # from helper-config
 invalid_pk = "qwerty"
 
 test_that("Valid account returns a 200 response with the expected fields.", {
@@ -14,7 +14,3 @@ test_that("Valid account returns a 200 response with the expected fields.", {
   }
 })
 
-test_that("Invalid accounts are handled appropriately.", {
-  expect_error(getAccountDetail(invalid_pk, domain = domain), "The resource at the url requested was not found")
-})
-
