@@ -1,10 +1,8 @@
 context("Find effects attached to a specific account.")
 
-valid_pk = "GCO2IP3MJNUOKS4PUDI4C7LGGMQDJGXG3COYX3WSB4HHNAHKYV5YL3VC"
+valid_pk = test_account_1 # from helper-config
 invalid_pk = "GAGAGAfsdafsadGA"
 
-
-
 test_that("Valid public key returns a 200 with the correct fields populated.", {
   e1 = getEffects_Account(valid_pk, domain = domain, data.table = FALSE)
   expect_false(is.data.table(e1))
